@@ -1,24 +1,39 @@
 var NAVTREEINDEX1 =
 {
+"group__libopenmpt__c.html#ga46bdc70e351674c787f0251c7ccbf1e1":[16,1,140],
+"group__libopenmpt__c.html#ga487b51694e4cf74a9727baf802380b53":[16,1,7],
+"group__libopenmpt__c.html#ga498bd8b7f699671ef573522cf908bc65":[16,1,107],
+"group__libopenmpt__c.html#ga4be8b5fad0607953cc760ca739ac3cb9":[16,1,156],
+"group__libopenmpt__c.html#ga4cf4b85e2b59b7e58c768791782a9657":[16,1,13],
+"group__libopenmpt__c.html#ga4d8caa2383f145fee70c7e97c3d2ffcc":[16,1,22],
+"group__libopenmpt__c.html#ga523fe9d172709472049941899c9835f2":[16,1,161],
+"group__libopenmpt__c.html#ga527b70571e44f6c4f0066d4a10670da4":[16,1,172],
+"group__libopenmpt__c.html#ga52a336127bf5176c8be2b2942fd43abc":[16,1,145],
+"group__libopenmpt__c.html#ga52ee99cdabedc1953682e347e5f77afb":[16,1,169],
+"group__libopenmpt__c.html#ga534305a50c22c68f4eb4735ac6e271db":[16,1,180],
+"group__libopenmpt__c.html#ga53dd106d28a4b68eea86fba6bfdd1b9a":[16,1,194],
+"group__libopenmpt__c.html#ga554202f4ecfabe476db5bb7c3df70c0c":[16,1,187],
 "group__libopenmpt__c.html#ga57a346d0443f50df673ef9d5119b3c76":[16,1,16],
-"group__libopenmpt__c.html#ga59437852eaaf2630813eb07edeb83aca":[16,1,142],
+"group__libopenmpt__c.html#ga59437852eaaf2630813eb07edeb83aca":[16,1,151],
 "group__libopenmpt__c.html#ga598311177f2b9ca335092ecb84b3dbf7":[16,1,33],
 "group__libopenmpt__c.html#ga5bf3273a05d37074f8c64b0354a2d9d4":[16,1,40],
 "group__libopenmpt__c.html#ga5d8d28ab0eef88f82c7ffbd28c39f361":[16,1,67],
-"group__libopenmpt__c.html#ga66079e450780e90840cefc9e167b95c6":[16,1,141],
+"group__libopenmpt__c.html#ga66079e450780e90840cefc9e167b95c6":[16,1,146],
 "group__libopenmpt__c.html#ga6611d57c2e5e6cc229bb6e013de8389a":[16,1,118],
-"group__libopenmpt__c.html#ga669eb6b76bfcdf2212f379495c28c3d2":[16,1,181],
+"group__libopenmpt__c.html#ga669eb6b76bfcdf2212f379495c28c3d2":[16,1,190],
 "group__libopenmpt__c.html#ga67648b980fac7134b5ac124d934d5750":[16,1,81],
 "group__libopenmpt__c.html#ga680c710bbbf3f23548f070335761b737":[16,1,34],
 "group__libopenmpt__c.html#ga6a3990be4d7140e255fbc96e1eaed3db":[16,1,95],
 "group__libopenmpt__c.html#ga6b636df734a1caa154886ae0ceb33ad7":[16,1,66],
 "group__libopenmpt__c.html#ga6c2d1e6b639673e3a098b00d8c92ffaa":[16,1,104],
+"group__libopenmpt__c.html#ga6c82d6d6075ac6b21b9b904b4a60d46b":[16,1,135],
+"group__libopenmpt__c.html#ga6d05792e881e995819d60f4a25d2ea5f":[16,1,144],
 "group__libopenmpt__c.html#ga6dc1e808a26084ffec15e3b159a22c0f":[16,1,35],
-"group__libopenmpt__c.html#ga6f062a0844fff3bdad604277954e6d75":[16,1,192],
-"group__libopenmpt__c.html#ga708932ad8fe819482a0f827993e73b20":[16,1,177],
+"group__libopenmpt__c.html#ga6f062a0844fff3bdad604277954e6d75":[16,1,201],
+"group__libopenmpt__c.html#ga708932ad8fe819482a0f827993e73b20":[16,1,186],
 "group__libopenmpt__c.html#ga7299bdb1270ac987339a5bab822a3973":[16,1,58],
 "group__libopenmpt__c.html#ga74d4ca58d5f5b6572df6334dc8290bb7":[16,1,59],
-"group__libopenmpt__c.html#ga7620687f3681690616dffe8d356f9df9":[16,1,135],
+"group__libopenmpt__c.html#ga7620687f3681690616dffe8d356f9df9":[16,1,137],
 "group__libopenmpt__c.html#ga789b4493a0ee3a3a6d145561bbbc2b97":[16,1,23],
 "group__libopenmpt__c.html#ga79c1fc512437220d9f65556723326c78":[16,1,88],
 "group__libopenmpt__c.html#ga79dbf8ac000b590e973971bd76262e9c":[16,1,69],
@@ -27,105 +42,108 @@ var NAVTREEINDEX1 =
 "group__libopenmpt__c.html#ga7b9523114368368950872b6235fe184c":[16,1,43],
 "group__libopenmpt__c.html#ga7bde366976a385ccb8711322d610c046":[16,1,18],
 "group__libopenmpt__c.html#ga7da0569dfb340b2d930a666e57dc1ccb":[16,1,129],
-"group__libopenmpt__c.html#ga7fc5bf2b846f790af1801bdc54aa7be2":[16,1,180],
-"group__libopenmpt__c.html#ga7ff2eac8523bb05b39b541ab21f02f2e":[16,1,145],
+"group__libopenmpt__c.html#ga7fc5bf2b846f790af1801bdc54aa7be2":[16,1,189],
+"group__libopenmpt__c.html#ga7ff2eac8523bb05b39b541ab21f02f2e":[16,1,154],
 "group__libopenmpt__c.html#ga7ffc363899565eebe05d38a670050c83":[16,1,99],
 "group__libopenmpt__c.html#ga80114288acfa1d1ae2bfdff571545c47":[16,1,101],
 "group__libopenmpt__c.html#ga8109c9c05bb3156183f1eead45a0cd13":[16,1,48],
 "group__libopenmpt__c.html#ga81b35d4ef8a335cc32e3cd605071cb0e":[16,1,8],
 "group__libopenmpt__c.html#ga86e37d405795dec88ea2efad19be8a30":[16,1,11],
-"group__libopenmpt__c.html#ga878b75edd4cac304994e54a2ad64ea26":[16,1,174],
+"group__libopenmpt__c.html#ga878b75edd4cac304994e54a2ad64ea26":[16,1,183],
 "group__libopenmpt__c.html#ga88048ecf1fe3a4b8bc6136d4d32954f4":[16,1,87],
-"group__libopenmpt__c.html#ga88b676fc5edca77f838ffa9610350661":[16,1,195],
+"group__libopenmpt__c.html#ga88b676fc5edca77f838ffa9610350661":[16,1,204],
 "group__libopenmpt__c.html#ga88bc398e2fedc565ef8747bf49abdae5":[16,1,62],
 "group__libopenmpt__c.html#ga88bd245db9a3e857443920bf68f093a6":[16,1,112],
 "group__libopenmpt__c.html#ga89b35d078ea9d92ff9c3c8ed09bbbd9c":[16,1,131],
 "group__libopenmpt__c.html#ga8a4b646f940bd9e9527dbda4edbeca17":[16,1,96],
 "group__libopenmpt__c.html#ga8ad3c291b61619556556bb991f3b62f8":[16,1,125],
-"group__libopenmpt__c.html#ga8ad927e7934b944badc6b63927105efd":[16,1,194],
+"group__libopenmpt__c.html#ga8ad927e7934b944badc6b63927105efd":[16,1,203],
 "group__libopenmpt__c.html#ga8ce40b6e5bebc76e080c3df197bf8839":[16,1,15],
-"group__libopenmpt__c.html#ga8d23ce5ccc5d3091f1b7f20f72ad30da":[16,1,193],
+"group__libopenmpt__c.html#ga8d23ce5ccc5d3091f1b7f20f72ad30da":[16,1,202],
 "group__libopenmpt__c.html#ga8dfe5edd28c6590c98eaeaa93e81a625":[16,1,71],
 "group__libopenmpt__c.html#ga8e0227f30332ba3a0b4cc1d6a330c2de":[16,1,27],
 "group__libopenmpt__c.html#ga8e1a6c3ad88b325825a4ec046500f322":[16,1,132],
-"group__libopenmpt__c.html#ga8e2766307479bcef46464d8bb2b957a6":[16,1,151],
-"group__libopenmpt__c.html#ga9101861fab39cd6993b206dc0270e6c5":[16,1,169],
+"group__libopenmpt__c.html#ga8e2766307479bcef46464d8bb2b957a6":[16,1,160],
+"group__libopenmpt__c.html#ga9101861fab39cd6993b206dc0270e6c5":[16,1,178],
 "group__libopenmpt__c.html#ga9195e24b064a56ce5f01107472d44db8":[16,1,83],
-"group__libopenmpt__c.html#ga92cdc66eb529a8a4a67987b659ed3c5e":[16,1,162],
-"group__libopenmpt__c.html#ga9507836c6d63771742d570919d417533":[16,1,134],
-"group__libopenmpt__c.html#ga9b222cad5195de39b84503c089eca611":[16,1,189],
+"group__libopenmpt__c.html#ga92cdc66eb529a8a4a67987b659ed3c5e":[16,1,171],
+"group__libopenmpt__c.html#ga9507836c6d63771742d570919d417533":[16,1,136],
+"group__libopenmpt__c.html#ga9b222cad5195de39b84503c089eca611":[16,1,198],
 "group__libopenmpt__c.html#ga9c185e78e8429d68c452eb187cf37151":[16,1,32],
 "group__libopenmpt__c.html#ga9f2013da0ddda5888d8ac9821193c269":[16,1,113],
 "group__libopenmpt__c.html#gaa0d7b531f0841d8cb8d264005d0328da":[16,1,14],
 "group__libopenmpt__c.html#gaa68155b220861de6218bc6b599071f21":[16,1,54],
 "group__libopenmpt__c.html#gaa739aee88cf80f57b9db1dd0bd57b356":[16,1,31],
 "group__libopenmpt__c.html#gaa74ca2c46b5f904f38adb928ca654173":[16,1,42],
-"group__libopenmpt__c.html#gaac34f4d87dd3c3e59b12daac81935d6c":[16,1,159],
-"group__libopenmpt__c.html#gaacc6e056e2161e64184079e0f23d34b0":[16,1,187],
-"group__libopenmpt__c.html#gaad2167f7a943f630a72af9b57a586491":[16,1,158],
+"group__libopenmpt__c.html#gaac34f4d87dd3c3e59b12daac81935d6c":[16,1,168],
+"group__libopenmpt__c.html#gaac5f19006300b8b96fe018b4bd4c2853":[16,1,134],
+"group__libopenmpt__c.html#gaacc6e056e2161e64184079e0f23d34b0":[16,1,196],
+"group__libopenmpt__c.html#gaad2167f7a943f630a72af9b57a586491":[16,1,167],
 "group__libopenmpt__c.html#gaadd84c34e34a322dd645df68923c7fe5":[16,1,127],
+"group__libopenmpt__c.html#gaafc73a581bbaaa666c374afb09b304de":[16,1,148],
 "group__libopenmpt__c.html#gab00cde7c1a2b17ebbecd677bd2e7c281":[16,1,117],
 "group__libopenmpt__c.html#gab178566ca8e2280f4389370200b00ad5":[16,1,93],
 "group__libopenmpt__c.html#gab2cd2489b8e9dd93af1811fb4bc9fd9b":[16,1,12],
-"group__libopenmpt__c.html#gab35f4ca3b71e20cabdc2febb5d48db87":[16,1,184],
-"group__libopenmpt__c.html#gab4376b1c2a9e995ee3cb12968d7e5705":[16,1,183],
+"group__libopenmpt__c.html#gab35f4ca3b71e20cabdc2febb5d48db87":[16,1,193],
+"group__libopenmpt__c.html#gab4376b1c2a9e995ee3cb12968d7e5705":[16,1,192],
 "group__libopenmpt__c.html#gab4cd78a172569a5d02c4e41c3caac18c":[16,1,90],
 "group__libopenmpt__c.html#gab4eedfb884356f25118f8782f088272e":[16,1,38],
+"group__libopenmpt__c.html#gab6262384476cd2143452e04a4a9b91ad":[16,1,149],
 "group__libopenmpt__c.html#gab7032a4db4a21f5b0ef8bd0ba53442e1":[16,1,60],
 "group__libopenmpt__c.html#gab90660d5d9fa932cfff118023c4b56c8":[16,1,110],
 "group__libopenmpt__c.html#gaba2d3014fed47caf598bb47b20acaee6":[16,1,45],
-"group__libopenmpt__c.html#gabb9d640ef27e3c289a88831a4ad28c7e":[16,1,149],
+"group__libopenmpt__c.html#gabb9d640ef27e3c289a88831a4ad28c7e":[16,1,158],
 "group__libopenmpt__c.html#gabd51630ad7af65f5fe71647446a241ed":[16,1,53],
 "group__libopenmpt__c.html#gac072d974496c651c863b3a5f4baae0d1":[16,1,50],
-"group__libopenmpt__c.html#gac17a6bc22e391cc4e5eafaa7f5fce9c9":[16,1,164],
+"group__libopenmpt__c.html#gac17a6bc22e391cc4e5eafaa7f5fce9c9":[16,1,173],
 "group__libopenmpt__c.html#gac21a4145f4f295b134117dd9ae7628d9":[16,1,78],
 "group__libopenmpt__c.html#gac2427d08b6fdd62376ca813543f91c9a":[16,1,28],
-"group__libopenmpt__c.html#gac310145e86bd88d5f38f3168073014fc":[16,1,144],
-"group__libopenmpt__c.html#gac337e452a17a4d4eee5c48f793774ba8":[16,1,175],
-"group__libopenmpt__c.html#gac4e234c38901822134feb37721ada825":[16,1,155],
+"group__libopenmpt__c.html#gac310145e86bd88d5f38f3168073014fc":[16,1,153],
+"group__libopenmpt__c.html#gac337e452a17a4d4eee5c48f793774ba8":[16,1,184],
+"group__libopenmpt__c.html#gac4e234c38901822134feb37721ada825":[16,1,164],
 "group__libopenmpt__c.html#gac53f78258568ddfb07be07ec33b1b9b6":[16,1,77],
 "group__libopenmpt__c.html#gac5daa1e631884cf990a326442a55f98a":[16,1,57],
 "group__libopenmpt__c.html#gac6e1f6ec3d9cc82fa3df5e63dc5b5350":[16,1,89],
-"group__libopenmpt__c.html#gac8331183f8a0a453f0fbdc4791fd79cb":[16,1,148],
-"group__libopenmpt__c.html#gac89b0366fe1f3686bcff1be86b69c79a":[16,1,190],
-"group__libopenmpt__c.html#gacc76d42781b233ba4717dcf0dc415eec":[16,1,167],
+"group__libopenmpt__c.html#gac8331183f8a0a453f0fbdc4791fd79cb":[16,1,157],
+"group__libopenmpt__c.html#gac89b0366fe1f3686bcff1be86b69c79a":[16,1,199],
+"group__libopenmpt__c.html#gacc76d42781b233ba4717dcf0dc415eec":[16,1,176],
 "group__libopenmpt__c.html#gaceaa2675b539674c1611d1e8a392aa87":[16,1,98],
-"group__libopenmpt__c.html#gad0ca32c54b27090e08005ccbb9477d3c":[16,1,138],
+"group__libopenmpt__c.html#gad0ca32c54b27090e08005ccbb9477d3c":[16,1,142],
 "group__libopenmpt__c.html#gad1db14545f64d123d1727026db01bdb3":[16,1,47],
 "group__libopenmpt__c.html#gad251165b289a9dcaa5ee91d189ffedff":[16,1,86],
 "group__libopenmpt__c.html#gad36da61e75bfb856174969636fa9a6f3":[16,1,24],
 "group__libopenmpt__c.html#gad4e86a00ec4879f9d654e11ac49fa768":[16,1,36],
 "group__libopenmpt__c.html#gad5bb8ddad658475f594e407c6366c25f":[16,1,39],
-"group__libopenmpt__c.html#gad9a89652e27fff8d2049970307f30d83":[16,1,166],
-"group__libopenmpt__c.html#gad9fe0ffe10b8410216caf238a83a93d2":[16,1,172],
+"group__libopenmpt__c.html#gad9a89652e27fff8d2049970307f30d83":[16,1,175],
+"group__libopenmpt__c.html#gad9fe0ffe10b8410216caf238a83a93d2":[16,1,181],
 "group__libopenmpt__c.html#gada5bfbb20e6bcb400eebda818d4bd84c":[16,1,102],
 "group__libopenmpt__c.html#gadb90c01fba5864c0359a28c2d4151dd7":[16,1,56],
 "group__libopenmpt__c.html#gadc9d6e523b44b9b4240893f3c56c3498":[16,1,52],
 "group__libopenmpt__c.html#gae10ab2bd98577a7023a211807889bd07":[16,1,76],
 "group__libopenmpt__c.html#gae183d049e057202eba8873f9a1c6b813":[16,1,25],
-"group__libopenmpt__c.html#gae2d0b54c815605e7f86d32e49bb8befc":[16,1,150],
+"group__libopenmpt__c.html#gae2d0b54c815605e7f86d32e49bb8befc":[16,1,159],
 "group__libopenmpt__c.html#gae376e59460c9b008e36616fb3737e030":[16,1,85],
-"group__libopenmpt__c.html#gae3ea99843d88c1575bf5ab9974d26c37":[16,1,179],
+"group__libopenmpt__c.html#gae3ea99843d88c1575bf5ab9974d26c37":[16,1,188],
 "group__libopenmpt__c.html#gae3ed09be74bd9e5dc78d424608a17e72":[16,1,111],
 "group__libopenmpt__c.html#gae476778edc6250c0cb6f02dd6bcfffcf":[16,1,74],
 "group__libopenmpt__c.html#gae4ebebf8546b5a94a2ec45c694ce9923":[16,1,20],
 "group__libopenmpt__c.html#gae64cad2f061106f0c26de34905c80c69":[16,1,91],
 "group__libopenmpt__c.html#gae8fa17a20133ebc64a26305aa181cc4c":[16,1,126],
-"group__libopenmpt__c.html#gae95f26d25828cd5c46e7a3b7d556b9f4":[16,1,165],
+"group__libopenmpt__c.html#gae95f26d25828cd5c46e7a3b7d556b9f4":[16,1,174],
 "group__libopenmpt__c.html#gaea002e826ecc42e0bcdcc07eb1340044":[16,1,21],
-"group__libopenmpt__c.html#gaecc775ac3096e1a1060941e0ef8ee0ec":[16,1,186],
+"group__libopenmpt__c.html#gaecc775ac3096e1a1060941e0ef8ee0ec":[16,1,195],
 "group__libopenmpt__c.html#gaeccd341852695cc71d8a5e3ac47ff168":[16,1,61],
-"group__libopenmpt__c.html#gaecd0bb67bb3b720340bb12f5df86db2a":[16,1,157],
-"group__libopenmpt__c.html#gaed6b9e12835aa9d17713eb1d8e8bed3b":[16,1,153],
+"group__libopenmpt__c.html#gaecd0bb67bb3b720340bb12f5df86db2a":[16,1,166],
+"group__libopenmpt__c.html#gaed6b9e12835aa9d17713eb1d8e8bed3b":[16,1,162],
 "group__libopenmpt__c.html#gaeec3c004981950af696bfd2688e250b2":[16,1,55],
-"group__libopenmpt__c.html#gaf5860bba2af2c4b02b8daa4539216f1a":[16,1,161],
+"group__libopenmpt__c.html#gaf5860bba2af2c4b02b8daa4539216f1a":[16,1,170],
 "group__libopenmpt__c.html#gaf5b929ef6551750bb10acf4a2fadc341":[16,1,63],
 "group__libopenmpt__c.html#gaf66aefb4747bd96fa12550ad7ebdb749":[16,1,10],
 "group__libopenmpt__c.html#gafb05f5927f7556affd014f3d89dcf47a":[16,1,100],
 "group__libopenmpt__c.html#gafcb88bda1d259fca5cc7beeeb2c9ec39":[16,1,103],
 "group__libopenmpt__c.html#gafe56244a9a28dc71e6b48d5fb006aa9a":[16,1,6],
 "group__libopenmpt__c.html#gaff2fbacf61b989e1f2987d9a8fbba371":[16,1,121],
-"group__libopenmpt__c.html#gaff805b4447e5e5164c5d49d08bb936d2":[16,1,170],
+"group__libopenmpt__c.html#gaff805b4447e5e5164c5d49d08bb936d2":[16,1,179],
 "group__libopenmpt__c.html#gaff878452d42b028d3c764794524f07cc":[16,1,72],
 "group__libopenmpt__c.html#gaff98a6ffecc468bd650b151c97fdc181":[16,1,30],
 "group__libopenmpt__cpp.html":[16,0],
@@ -231,23 +249,5 @@ var NAVTREEINDEX1 =
 "libopenmpt__stream__callbacks__file__msvcrt_8h_source.html":[19,0,1,9],
 "libopenmpt__stream__callbacks__file__posix_8h.html":[19,0,1,10],
 "libopenmpt__stream__callbacks__file__posix_8h_source.html":[19,0,1,10],
-"libopenmpt__stream__callbacks__file__posix__lfs64_8h.html":[19,0,1,11],
-"libopenmpt__stream__callbacks__file__posix__lfs64_8h_source.html":[19,0,1,11],
-"libopenmpt__version_8h.html":[19,0,1,12],
-"libopenmpt__version_8h_source.html":[19,0,1,12],
-"libopenmpt_c_overview.html":[12],
-"libopenmpt_c_overview.html#libopenmpt_c_detailed":[12,6],
-"libopenmpt_c_overview.html#libopenmpt_c_error":[12,0],
-"libopenmpt_c_overview.html#libopenmpt_c_example_file":[12,7,1],
-"libopenmpt_c_overview.html#libopenmpt_c_example_inmemory":[12,7,2],
-"libopenmpt_c_overview.html#libopenmpt_c_example_stdout":[12,7,3],
-"libopenmpt_c_overview.html#libopenmpt_c_example_unsafe":[12,7,0],
-"libopenmpt_c_overview.html#libopenmpt_c_examples":[12,7],
-"libopenmpt_c_overview.html#libopenmpt_c_fileio":[12,2],
-"libopenmpt_c_overview.html#libopenmpt_c_outputformat":[12,3],
-"libopenmpt_c_overview.html#libopenmpt_c_staticlinking":[12,5],
-"libopenmpt_c_overview.html#libopenmpt_c_strings":[12,1],
-"libopenmpt_c_overview.html#libopenmpt_c_threads":[12,4],
-"libopenmpt_cpp_overview.html":[11],
-"libopenmpt_cpp_overview.html#libopenmpt-cpp-detailed":[11,6]
+"libopenmpt__stream__callbacks__file__posix__lfs64_8h.html":[19,0,1,11]
 };
